Codex Autorunner

–

repos

–

running

–

missing

Usage –
Loading…
Usage Trend
Repositories
Loading…
Runner Status v–
idle

Run ID

–

Exit

–

Started

–

Finished

–

TODO

–

Done

–

Model auto

PID: –

Usage – –
– in
– cached
– out
– reason
Trend
Primary
Secondary
TODO

GitHub –
Repo –
Branch –
Issue –
PR –

–

Pending patch
Added Removed
(no patch)
Cmd+Enter/Ctrl+Enter to send · Enter for newline idle
History 0
Run Tail
Timestamp Run
Thinking Tool calls File updates Added Removed Agent output Context

    (no log loaded)

Disconnected

Press New or Resume to launch Codex TUI

Text input
Confirmation

Input

Create New Repository
Repo ID * Used as directory name if path not specified
Path (optional) Leave empty to use repo ID as path
Git URL (optional) If provided, the repo will be cloned automatically
Initialize git repository
Hub Settings

System-wide settings for Codex Autorunner.

System Update
Pull latest code and restart selected services
Repo Settings

Settings for the current repository session.

System Update
Pull latest code and restart selected services